==> myfaces-tobago-4.5.5-source-release.zip: tobago-4.5.5/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ButtonLinkController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.inject.Named;
import java.io.Serializable;

@Named
public class ButtonLinkController implements Serializable {

  private static final Logger LOG = LoggerFactory.getLogger(ButtonLinkController.class);

  public String linkToComponentsRoot() {
    LOG.info("link to components root");
    return "/content/20-component/component.xhtml?faces-redirect=true";
  }

  public String actionPage() {
    LOG.info("link to action.xhtml");
    return "/content/40-test/4000-button+link/x-action.xhtml?faces-redirect=true";
  }

  public String targetActionPage() {
    LOG.info("link to targetAction.xhtml");
    return "/content/40-test/4000-button+link/x-targetAction.xhtml";
  }
}

==> myfaces-tobago-5.7.1-source-release.zip: tobago-5.7.1/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ButtonLinkController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.enterprise.context.RequestScoped;
import javax.inject.Named;
import java.io.Serializable;
import java.lang.invoke.MethodHandles;

@Named
@RequestScoped
public class ButtonLinkController implements Serializable {

  private static final Logger LOG = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());

  public Outcome linkToCommandsRoot() {
    LOG.info("link to components root");
    return Outcome.COMMAND;
  }

  public Outcome actionPage() {
    LOG.info("link to action.xhtml");
    return Outcome.TEST_BUTTONLINK_XACTION;
  }

  public Outcome targetActionPage() {
    LOG.info("link to targetAction.xhtml");
    return Outcome.TEST_BUTTONLINK_XTARGETACTION;
  }
}
